GLMM_MCMCprior.b:
Handle prior.eps argument of GLMM_MCMC function
Description
This is a help function for GLMM_MCMC function.
THIS FUNCTION IS NOT TO BE CALLED BY ORDINARY USERS.
Usage
GLMM_MCMCprior.b(prior.b, scale.b, dimb, iEranefVec, iSDranefVec)
Arguments
iEranefVec
see output element iEranefVec of GLMM_MCMCifit
function. Defaults to a vector of zeros if missing iSDranefVec
see output element iSDranefVec of GLMM_MCMCifit
function. Defaults to a vector of ones if missing Value
A list with the following components:
- prior.b
- value of
prior.b with added default values
where necessary - CpriorInt_b
- a numeric vector to be passed to C++
- CpriorDouble_b
- a numeric vector to be passed to C++