Learn R Programming

mixAK (version 0.4)

NMixClust: Clustering based on a mixture model

Description

It performs clustering based on posterior summary for (re-labeled) mixture components in a model with fixed number of components fitted with NMixMCMC function.

Usage

NMixClust(object, y)

Arguments

object
an object of class NMixMCMC
y
vector, matrix or data frame with observations to be clustered

Value

  • A data.frame with observations in the first columns and additionally columns labeled prob1,..., probp giving posterior probabilities of belonging to each component and a column labeled component giving the index of the component with the highest posterior probability.

See Also

NMixMCMC.