Also pseudo degrees of freedom are returned which are equal to a number of hyperrectangles minus number of free parameters of the normal mixture. For a $K$-component mixture of dimension $p$, the number of free parameters is computed as $$q = K-1 + K\cdot p + K\cdot p(p+1)/2$$ Note that computation of $q$ does not take into account the positive (semi-)definiteness restriction on covariance matrices.
WARNING: There is no statistical theory developed that would guarantee that computed chi-squared like statistics follows a chi-squared distribution with computed pseudo degrees of freedom under the null hypothesis that the distribution that generated the data is a normal mixture. This function serves purely for descriptive purposes!
NMixPseudoGOF(x, ...)
"NMixPseudoGOF"(x, scale, w, mu, Sigma, breaks, nbreaks=10, digits=3, ...)
"NMixPseudoGOF"(x, y, breaks, nbreaks=10, digits=3, ...)y below) for
NMixPseudoGOF.default function. An object of class NMixMCMC for
NMixPseudoGOF.NMixMCMC function.
shift and the
scale. If not given, shift is equal to zero and scale is
equal to one.
mu has
$K$ rows and $p$ columns, where $K$ denotes the number
of mixture components and $p$ is dimension of the mixture
distribution.
breaks is
not given to determine sensible break values.
NMixMCMC.