Currently, this function creates chains for marginal means
of exp(data) from previously sampled values (see NMixMCMC).
This is useful in survival context when a density
of \(Y=\log(T)\) is modelled using the function
NMixMCMC and we are interested in inference
on \(\mbox{E}T = \mbox{E}\exp(Y)\).
NMixChainsDerived(object)an object of class NMixMCMC or NMixMCMClist
An object of the same class as argument object. When
object was of class NMixMCMC, the resulting object
contains additionally the following components:
a data.frame with columns labeled
expy.Mean.1, …, expy.Mean.p containing the
sampled values of \(\mbox{E}\exp(Y_1)\), …,
\(\mbox{E}\exp(Y_p)\).
posterior summary statistics for \(\mbox{E}\exp(Y_1)\), …, \(\mbox{E}\exp(Y_p)\).